Documentation
¶
Overview ¶
Package tpoll is an advanced library and toolset for polling large amounts of network devices, initially with SNMP, but conceptually with any relevant protocol.
It works, or will work, through a central work-distribution database/api, and multiple, largely independent pollers. The results are reported using Skogul.
Index ¶
Constants ¶
This section is empty.
Variables ¶
Functions ¶
Types ¶
type Node ¶
type Node struct {
Key string // original input key, kept for posterity
Name string
Numeric string // I KNOW
Qualified string
Lookedup bool // True if key was not a pure OID
}
Node is a rendered SMI node, e.g.: the result of a lookup. Usually handled by the smierte sub-package, but needs to be defined up here to avoid circular dependencies
Directories
¶
| Path | Synopsis |
|---|---|
|
cmd
|
|
|
addjob
command
|
|
|
tpoll
command
PS: While this started with a gosnmp walk-example, basically nothing is left of that, which is why I just removed the original copyright header, if you happen to be reading the git log.
|
PS: While this started with a gosnmp walk-example, basically nothing is left of that, which is why I just removed the original copyright header, if you happen to be reading the git log. |
|
Package inventory deals with inventory locking and syncing.
|
Package inventory deals with inventory locking and syncing. |
Click to show internal directories.
Click to hide internal directories.